@@ -1,5 +1,5 @@
 package Exporter::Extensible;
-BEGIN { $Exporter::Extensible::VERSION = '0.02'; }
+BEGIN { $Exporter::Extensible::VERSION = '0.03'; }
 use v5.12;
 use strict;
 use warnings;
@@ -30,10 +30,10 @@ our %reftype_to_sigil= (
 	'CODE'   => '',
 );
 our %sigil_to_generator_prefix= (
-	'$' => '_generateSCALAR_',
-	'@' => '_generateARRAY_',
-	'%' => '_generateHASH_',
-	'*' => '_generateGLOB_',
+	'$' => '_generateScalar_',
+	'@' => '_generateArray_',
+	'%' => '_generateHash_',
+	'*' => '_generateGlob_',
 	'&' => '_generate_',
 	''  => '_generate_',
 );
@@ -54,6 +54,8 @@ sub import {
 	my $inventory= $EXPORT_PKG_CACHE{ref $self} ||= {};
 	my $install= $self->{install_set} ||= {};
 	
+	unshift @_, $self->exporter_get_tag_members('default')
+		unless @_;
 	for (my $i= 0; $i < @_;) {
 		my $symbol= $_[$i++];
 		my ($sigil, $name)= ($symbol =~ /^([-:\$\@\%\*]?)(.*)/); # should always match
@@ -408,7 +410,7 @@ sub exporter_get_tag_members {
 				# Found a generator (coderef or method name ref).  Call it to get the list of tags.
 				$add= ref $add eq 'CODE'? $add
 					: ref $add eq 'SCALAR'? $$add
-					: _croak("Tag must expand to an array, code, or a method name ref");
+					: _croak("Tag must expand to an array, code, or a method name ref (not $add)");
 				$add= $self->$add($self->{generator_arg});
 				ref $add eq 'ARRAY' or _croak("Tag generator must return an arrayref");
 				++$dynamic;
@@ -544,6 +546,13 @@ sub exporter_setup {
 	strict->import;
 	warnings->import;
 	if ($version == 1) {
+		# Make @EXPORT and $EXPORT_TAGS{default} be the same arrayref.
+		# Allow either one to have been declared already.
+		my $tags= \%{$self->{into}.'::EXPORT_TAGS'};
+		*{$self->{into}.'::EXPORT'}= $tags->{default}
+			if ref $tags->{default} eq 'ARRAY';
+		$tags->{default} ||= \@{$self->{into}.'::EXPORT'};
+		# Export the 'export' function.
 		*{$self->{into}.'::export'}= \&_exporter_export_from_caller;
 	}
 	elsif ($version) {
@@ -632,7 +641,7 @@ Exporter::Extensible - Create easy-to-extend modules which export symbols
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -813,7 +822,7 @@ Determines what to do if the symbol already exists in the target package:
 
 =over
 
-=item 1
+=item C<1>
 
 Replace the symbol with no warning.
 
@@ -915,29 +924,29 @@ refs.  If the value is omitted, C<export> attempts to do-what-you-mean to find i
 
 =over
 
-=item 'foo' => \&CODE
+=item C<< foo => \&CODE >>
 
-This declares a normal exported function.  If the ref is omitted, C<export> looks for it in the
-hierarchy of the current package.  Note that this lookup happens immediately, and packages
-derived from this cannot override C<foo> and have that be exported in its place.
+This declares a normal exported function.  If the ref is omitted, C<export> looks for it in
+the the current package.  Note that this lookup happens immediately, so derived packages that
+want to override C<foo> must re-declare it.
 
-=item '$foo' => \$SCALAR, '@foo' => \@ARRAY, '%foo' => \%HASH, '*foo' => \*GLOB
+=item C<< '$foo' => \$SCALAR >>, C<< '@foo' => \@ARRAY >>, C<< '%foo' => \%HASH >>, C<< '*foo' => \*GLOB >>
 
 This exports a normal variable or typeglob.  If the ref is omitted, C<export> looks for it
 in the current package.
 
-=item '-foo' => $CODEREF or '-foo' => \"methodname"
+=item C<< -foo => $CODEREF >> or C<< -foo => \"methodname" >>
 
 This differs from a normal exported function in that it will execute the coderef at import time,
 and sub-packages B<can> override it, since it gets called as a method.  The default is to derive
 the method name by removing the C<->.
 
-=item ':foo' => \@LIST
+=item C<< ':foo' => \@LIST >>
 
 Declaring a tag is nothing special; just give it an arrayref of what should be imported when
 the tag is encountered.
 
-=item '=$foo' => $CODEREF or '=$foo' => \"methodname"
+=item C<< '=$foo' => $CODEREF >> or C<< '=$foo' => \"methodname" >>
 
 Prefixing an export name with an equal sign means you want to generate the export on the fly.
 The ref is understood to be the coderef or method name to call (as a method) which will return
@@ -996,23 +1005,23 @@ L</export> function.  You may include one or more of the following in the parent
 
 =over
 
-=item 'foo'
+=item C<< foo >>
 
 This indicates the export-name of a sub.  A sub may be exported as more than one name.
 Note that the first name in the list becomes the official name (ignoring the actual name of
 the sub) which will be added to any tags you listed.
 
-=item ':foo'
+=item C<< :foo >>
 
 This requests that the export-name get added to the named tag.  You may specify any number of
 tags.
 
-=item '-', '-(N)', '-foo', '-foo(N)'
+=item C<< - >>, C<< -(N) >>, C<< -foo >>, C<< -foo(N) >>
 
 This sets up the sub as an option, capturing N arguments.  In the cases without a name, the
 name of the sub is used.  N may be C<'*'> or C<'?'>; see L</IMPLEMENTING OPTIONS>.
 
-=item '=', '=$', '=@', '=%', '=*', '=foo', '=$foo', ...
+=item C<< = >>, C<< =$ >>, C<< =@ >>, C<< =% >>, C<< =* >>, C<< =foo >>, C<< =$foo >>, ...
 
 This sets up the sub as a generator for the export-name.  If the word portion of the name is
 omitted, it is taken to be the sub name minus the prefix "_generate_" or "_generate$REFTYPE_".
@@ -1070,13 +1079,13 @@ option decide how many arguments to consume.  So, the API is as follows:
   # By default, no arguments are captured.  A ref may not follow this option.
   sub name : Export( -name ) {
     my $exporter= shift;
-	...
+    ...
   }
   
   # Ask for three arguments (regardless of whether they are refs)
   sub name : Export( -name(3) ) {
-     my ($exporter, $arg1, $arg2, $arg3)= @_;
-	 ...
+    my ($exporter, $arg1, $arg2, $arg3)= @_;
+    ...
   }
   
   # Ask for one argument but only if it is a ref of some kind.
@@ -1085,16 +1094,16 @@ option decide how many arguments to consume.  So, the API is as follows:
     my ($exporter, $maybe_arg)= @_;
     ...
   }
-
+  
   # Might need any number of arguments.  Return the number we consumed.
   sub name : Export( -name(*) ) {
     my $exporter = shift;
-	while (@_) {
-	   last if ...;
-	   ...
-	   ++$consumed;
+    while (@_) {
+      last if ...;
+      ...
+      ++$consumed;
     }
-	return $consumed;
+    return $consumed;
   }
 
 The first argument C<$exporter> is a instance of the exporting package, and you can inspect it
@@ -1119,8 +1128,8 @@ generator can retrieve the values from there.
   export(
     # be sure to use names that won't conflict with Exporter::Extensible's internals
     '-foo(1)' => sub { shift->{foo}= shift },
-	'-bar(1)' => sub { shift->{bar}= shift },
-	'=foobar' => sub { my $foobar= $_[0]{foo} . $_[0]{bar}; sub { $foobar } },
+    '-bar(1)' => sub { shift->{bar}= shift },
+    '=foobar' => sub { my $foobar= $_[0]{foo} . $_[0]{bar}; sub { $foobar } },
   );
   
   package User;
